Method: Aws::Appflow::Client#update_connector_registration

Defined in:
lib/aws-sdk-appflow/client.rb

#update_connector_registration(params = {}) ⇒ Types::UpdateConnectorRegistrationResponse

Updates a custom connector that you’ve previously registered. This operation updates the connector with one of the following:

  • The latest version of the AWS Lambda function that’s assigned to the connector

  • A new AWS Lambda function that you specify

Examples:

Request syntax with placeholder values


resp = client.update_connector_registration({
  connector_label: "ConnectorLabel", # required
  description: "Description",
  connector_provisioning_config: {
    lambda: {
      lambda_arn: "ARN", # required
    },
  },
  client_token: "ClientToken",
})

Response structure


resp.connector_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :connector_label (required, String)

    The name of the connector. The name is unique for each connector registration in your AWS account.

  • :description (String)

    A description about the update that you’re applying to the connector.

  • :connector_provisioning_config (Types::ConnectorProvisioningConfig)

    Contains information about the configuration of the connector being registered.

  • :client_token (String)

    The clientToken parameter is an idempotency token. It ensures that your UpdateConnectorRegistration request completes only once. You choose the value to pass. For example, if you don’t receive a response from your request, you can safely retry the request with the same clientToken parameter value.

    If you omit a clientToken value, the Amazon Web Services SDK that you are using inserts a value for you. This way, the SDK can safely retry requests multiple times after a network error. You must provide your own value for other use cases.

    If you specify input parameters that differ from your first request, an error occurs. If you use a different value for clientToken, Amazon AppFlow considers it a new call to UpdateConnectorRegistration. The token is active for 8 hours.

    **A suitable default value is auto-generated.** You should normally not need to pass this option.**

Returns:

See Also:



2990
2991
2992
2993
# File 'lib/aws-sdk-appflow/client.rb', line 2990

def update_connector_registration(params = {}, options = {})
  req = build_request(:update_connector_registration, params)
  req.send_request(options)
end