Class: Aws::Appflow::Types::ConnectorProfile

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appflow/types.rb

Overview

Describes an instance of a connector. This includes the provided name, credentials ARN, connection-mode, and so on. To keep the API intuitive and extensible, the fields that are common to all types of connector profiles are explicitly specified at the top level. The rest of the connector-specific properties are available via the connectorProfileProperties field.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_modeString

Indicates the connection mode and if it is public or private.

Returns:

  • (String)


930
931
932
933
934
935
936
937
938
939
940
941
942
943
# File 'lib/aws-sdk-appflow/types.rb', line 930

class ConnectorProfile < Struct.new(
  :connector_profile_arn,
  :connector_profile_name,
  :connector_type,
  :connector_label,
  :connection_mode,
  :credentials_arn,
  :connector_profile_properties,
  :created_at,
  :last_updated_at,
  :private_connection_provisioning_state)
  SENSITIVE = []
  include Aws::Structure
end

#connector_labelString

The label for the connector profile being created.

Returns:

  • (String)


930
931
932
933
934
935
936
937
938
939
940
941
942
943
# File 'lib/aws-sdk-appflow/types.rb', line 930

class ConnectorProfile < Struct.new(
  :connector_profile_arn,
  :connector_profile_name,
  :connector_type,
  :connector_label,
  :connection_mode,
  :credentials_arn,
  :connector_profile_properties,
  :created_at,
  :last_updated_at,
  :private_connection_provisioning_state)
  SENSITIVE = []
  include Aws::Structure
end

#connector_profile_arnString

The Amazon Resource Name (ARN) of the connector profile.

Returns:

  • (String)


930
931
932
933
934
935
936
937
938
939
940
941
942
943
# File 'lib/aws-sdk-appflow/types.rb', line 930

class ConnectorProfile < Struct.new(
  :connector_profile_arn,
  :connector_profile_name,
  :connector_type,
  :connector_label,
  :connection_mode,
  :credentials_arn,
  :connector_profile_properties,
  :created_at,
  :last_updated_at,
  :private_connection_provisioning_state)
  SENSITIVE = []
  include Aws::Structure
end

#connector_profile_nameString

The name of the connector profile. The name is unique for each ConnectorProfile in the Amazon Web Services account.

Returns:

  • (String)


930
931
932
933
934
935
936
937
938
939
940
941
942
943
# File 'lib/aws-sdk-appflow/types.rb', line 930

class ConnectorProfile < Struct.new(
  :connector_profile_arn,
  :connector_profile_name,
  :connector_type,
  :connector_label,
  :connection_mode,
  :credentials_arn,
  :connector_profile_properties,
  :created_at,
  :last_updated_at,
  :private_connection_provisioning_state)
  SENSITIVE = []
  include Aws::Structure
end

#connector_profile_propertiesTypes::ConnectorProfileProperties

The connector-specific properties of the profile configuration.



930
931
932
933
934
935
936
937
938
939
940
941
942
943
# File 'lib/aws-sdk-appflow/types.rb', line 930

class ConnectorProfile < Struct.new(
  :connector_profile_arn,
  :connector_profile_name,
  :connector_type,
  :connector_label,
  :connection_mode,
  :credentials_arn,
  :connector_profile_properties,
  :created_at,
  :last_updated_at,
  :private_connection_provisioning_state)
  SENSITIVE = []
  include Aws::Structure
end

#connector_typeString

The type of connector, such as Salesforce, Amplitude, and so on.

Returns:

  • (String)


930
931
932
933
934
935
936
937
938
939
940
941
942
943
# File 'lib/aws-sdk-appflow/types.rb', line 930

class ConnectorProfile < Struct.new(
  :connector_profile_arn,
  :connector_profile_name,
  :connector_type,
  :connector_label,
  :connection_mode,
  :credentials_arn,
  :connector_profile_properties,
  :created_at,
  :last_updated_at,
  :private_connection_provisioning_state)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

Specifies when the connector profile was created.

Returns:

  • (Time)


930
931
932
933
934
935
936
937
938
939
940
941
942
943
# File 'lib/aws-sdk-appflow/types.rb', line 930

class ConnectorProfile < Struct.new(
  :connector_profile_arn,
  :connector_profile_name,
  :connector_type,
  :connector_label,
  :connection_mode,
  :credentials_arn,
  :connector_profile_properties,
  :created_at,
  :last_updated_at,
  :private_connection_provisioning_state)
  SENSITIVE = []
  include Aws::Structure
end

#credentials_arnString

The Amazon Resource Name (ARN) of the connector profile credentials.

Returns:

  • (String)


930
931
932
933
934
935
936
937
938
939
940
941
942
943
# File 'lib/aws-sdk-appflow/types.rb', line 930

class ConnectorProfile < Struct.new(
  :connector_profile_arn,
  :connector_profile_name,
  :connector_type,
  :connector_label,
  :connection_mode,
  :credentials_arn,
  :connector_profile_properties,
  :created_at,
  :last_updated_at,
  :private_connection_provisioning_state)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_atTime

Specifies when the connector profile was last updated.

Returns:

  • (Time)


930
931
932
933
934
935
936
937
938
939
940
941
942
943
# File 'lib/aws-sdk-appflow/types.rb', line 930

class ConnectorProfile < Struct.new(
  :connector_profile_arn,
  :connector_profile_name,
  :connector_type,
  :connector_label,
  :connection_mode,
  :credentials_arn,
  :connector_profile_properties,
  :created_at,
  :last_updated_at,
  :private_connection_provisioning_state)
  SENSITIVE = []
  include Aws::Structure
end

#private_connection_provisioning_stateTypes::PrivateConnectionProvisioningState

Specifies the private connection provisioning state.



930
931
932
933
934
935
936
937
938
939
940
941
942
943
# File 'lib/aws-sdk-appflow/types.rb', line 930

class ConnectorProfile < Struct.new(
  :connector_profile_arn,
  :connector_profile_name,
  :connector_type,
  :connector_label,
  :connection_mode,
  :credentials_arn,
  :connector_profile_properties,
  :created_at,
  :last_updated_at,
  :private_connection_provisioning_state)
  SENSITIVE = []
  include Aws::Structure
end