Class: Aws::Appflow::Types::CustomConnectorProfileCredentials

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appflow/types.rb

Overview

The connector-specific profile credentials that are required when using the custom connector.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#api_key ⇒ Types::ApiKeyCredentials

The API keys required for the authentication of the user.



1546
1547
1548
1549
1550
1551
1552
1553
1554
# File 'lib/aws-sdk-appflow/types.rb', line 1546

class CustomConnectorProfileCredentials < Struct.new(
  :authentication_type,
  :basic,
  :oauth2,
  :api_key,
  :custom)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_type ⇒ String

The authentication type that the custom connector uses for authenticating while creating a connector profile.

Returns:

  • (String)


1546
1547
1548
1549
1550
1551
1552
1553
1554
# File 'lib/aws-sdk-appflow/types.rb', line 1546

class CustomConnectorProfileCredentials < Struct.new(
  :authentication_type,
  :basic,
  :oauth2,
  :api_key,
  :custom)
  SENSITIVE = []
  include Aws::Structure
end

#basic ⇒ Types::BasicAuthCredentials

The basic credentials that are required for the authentication of the user.



1546
1547
1548
1549
1550
1551
1552
1553
1554
# File 'lib/aws-sdk-appflow/types.rb', line 1546

class CustomConnectorProfileCredentials < Struct.new(
  :authentication_type,
  :basic,
  :oauth2,
  :api_key,
  :custom)
  SENSITIVE = []
  include Aws::Structure
end

#custom ⇒ Types::CustomAuthCredentials

If the connector uses the custom authentication mechanism, this holds the required credentials.



1546
1547
1548
1549
1550
1551
1552
1553
1554
# File 'lib/aws-sdk-appflow/types.rb', line 1546

class CustomConnectorProfileCredentials < Struct.new(
  :authentication_type,
  :basic,
  :oauth2,
  :api_key,
  :custom)
  SENSITIVE = []
  include Aws::Structure
end

#oauth2 ⇒ Types::OAuth2Credentials

The OAuth 2.0 credentials required for the authentication of the user.



1546
1547
1548
1549
1550
1551
1552
1553
1554
# File 'lib/aws-sdk-appflow/types.rb', line 1546

class CustomConnectorProfileCredentials < Struct.new(
  :authentication_type,
  :basic,
  :oauth2,
  :api_key,
  :custom)
  SENSITIVE = []
  include Aws::Structure
end