Class: Aws::Appflow::Types::CustomerProfilesDestinationProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appflow/types.rb

Overview

The properties that are applied when Connect Customer Customer Profiles is used as a destination.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_nameString

The unique name of the Connect Customer Customer Profiles domain.

Returns:

  • (String)


1612
1613
1614
1615
1616
1617
# File 'lib/aws-sdk-appflow/types.rb', line 1612

class CustomerProfilesDestinationProperties < Struct.new(
  :domain_name,
  :object_type_name)
  SENSITIVE = []
  include Aws::Structure
end

#object_type_nameString

The object specified in the Connect Customer Customer Profiles flow destination.

Returns:

  • (String)


1612
1613
1614
1615
1616
1617
# File 'lib/aws-sdk-appflow/types.rb', line 1612

class CustomerProfilesDestinationProperties < Struct.new(
  :domain_name,
  :object_type_name)
  SENSITIVE = []
  include Aws::Structure
end