Class: Aws::Appflow::Types::DatadogConnectorProfileCredentials

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appflow/types.rb

Overview

The connector-specific credentials required by Datadog.

Constant Summary collapse

SENSITIVE =
[:api_key]

Instance Attribute Summary collapse

Instance Attribute Details

#api_keyString

A unique alphanumeric identifier used to authenticate a user, developer, or calling program to your API.

Returns:

  • (String)


1684
1685
1686
1687
1688
1689
# File 'lib/aws-sdk-appflow/types.rb', line 1684

class DatadogConnectorProfileCredentials < Struct.new(
  :api_key,
  :application_key)
  SENSITIVE = [:api_key]
  include Aws::Structure
end

#application_keyString

Application keys, in conjunction with your API key, give you full access to Datadog’s programmatic API. Application keys are associated with the user account that created them. The application key is used to log all requests made to the API.

Returns:

  • (String)


1684
1685
1686
1687
1688
1689
# File 'lib/aws-sdk-appflow/types.rb', line 1684

class DatadogConnectorProfileCredentials < Struct.new(
  :api_key,
  :application_key)
  SENSITIVE = [:api_key]
  include Aws::Structure
end