Class: Aws::Appflow::Types::GoogleAnalyticsConnectorProfileCredentials
- Inherits:
-
Struct
- Object
- Struct
- Aws::Appflow::Types::GoogleAnalyticsConnectorProfileCredentials
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appflow/types.rb
Overview
The connector-specific profile credentials required by Google Analytics.
Constant Summary collapse
- SENSITIVE =
[:client_secret, :access_token]
Instance Attribute Summary collapse
-
#access_token ⇒ String
The credentials used to access protected Google Analytics resources.
-
#client_id ⇒ String
The identifier for the desired client.
-
#client_secret ⇒ String
The client secret used by the OAuth client to authenticate to the authorization server.
-
#o_auth_request ⇒ Types::ConnectorOAuthRequest
The OAuth requirement needed to request security tokens from the connector endpoint.
-
#refresh_token ⇒ String
The credentials used to acquire new access tokens.
Instance Attribute Details
#access_token ⇒ String
The credentials used to access protected Google Analytics resources.
2750 2751 2752 2753 2754 2755 2756 2757 2758 |
# File 'lib/aws-sdk-appflow/types.rb', line 2750 class GoogleAnalyticsConnectorProfileCredentials < Struct.new( :client_id, :client_secret, :access_token, :refresh_token, :o_auth_request) SENSITIVE = [:client_secret, :access_token] include Aws::Structure end |
#client_id ⇒ String
The identifier for the desired client.
2750 2751 2752 2753 2754 2755 2756 2757 2758 |
# File 'lib/aws-sdk-appflow/types.rb', line 2750 class GoogleAnalyticsConnectorProfileCredentials < Struct.new( :client_id, :client_secret, :access_token, :refresh_token, :o_auth_request) SENSITIVE = [:client_secret, :access_token] include Aws::Structure end |
#client_secret ⇒ String
The client secret used by the OAuth client to authenticate to the authorization server.
2750 2751 2752 2753 2754 2755 2756 2757 2758 |
# File 'lib/aws-sdk-appflow/types.rb', line 2750 class GoogleAnalyticsConnectorProfileCredentials < Struct.new( :client_id, :client_secret, :access_token, :refresh_token, :o_auth_request) SENSITIVE = [:client_secret, :access_token] include Aws::Structure end |
#o_auth_request ⇒ Types::ConnectorOAuthRequest
The OAuth requirement needed to request security tokens from the connector endpoint.
2750 2751 2752 2753 2754 2755 2756 2757 2758 |
# File 'lib/aws-sdk-appflow/types.rb', line 2750 class GoogleAnalyticsConnectorProfileCredentials < Struct.new( :client_id, :client_secret, :access_token, :refresh_token, :o_auth_request) SENSITIVE = [:client_secret, :access_token] include Aws::Structure end |
#refresh_token ⇒ String
The credentials used to acquire new access tokens. This is required only for OAuth2 access tokens, and is not required for OAuth1 access tokens.
2750 2751 2752 2753 2754 2755 2756 2757 2758 |
# File 'lib/aws-sdk-appflow/types.rb', line 2750 class GoogleAnalyticsConnectorProfileCredentials < Struct.new( :client_id, :client_secret, :access_token, :refresh_token, :o_auth_request) SENSITIVE = [:client_secret, :access_token] include Aws::Structure end |