Class: Aws::Appflow::Types::PrefixConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appflow/types.rb

Overview

Specifies elements that Amazon AppFlow includes in the file and folder names in the flow destination.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#path_prefix_hierarchyArray<String>

Specifies whether the destination file path includes either or both of the following elements:

EXECUTION_ID

: The ID that Amazon AppFlow assigns to the flow run.

SCHEMA_VERSION

: The version number of your data schema. Amazon AppFlow assigns

this version number. The version number increases by one when you
change any of the following settings in your flow configuration:

* Source-to-destination field mappings

* Field data types

* Partition keys

Returns:

  • (Array<String>)


3629
3630
3631
3632
3633
3634
3635
# File 'lib/aws-sdk-appflow/types.rb', line 3629

class PrefixConfig < Struct.new(
  :prefix_type,
  :prefix_format,
  :path_prefix_hierarchy)
  SENSITIVE = []
  include Aws::Structure
end

#prefix_formatString

Determines the level of granularity for the date and time that’s included in the prefix.

Returns:

  • (String)


3629
3630
3631
3632
3633
3634
3635
# File 'lib/aws-sdk-appflow/types.rb', line 3629

class PrefixConfig < Struct.new(
  :prefix_type,
  :prefix_format,
  :path_prefix_hierarchy)
  SENSITIVE = []
  include Aws::Structure
end

#prefix_typeString

Determines the format of the prefix, and whether it applies to the file name, file path, or both.

Returns:

  • (String)


3629
3630
3631
3632
3633
3634
3635
# File 'lib/aws-sdk-appflow/types.rb', line 3629

class PrefixConfig < Struct.new(
  :prefix_type,
  :prefix_format,
  :path_prefix_hierarchy)
  SENSITIVE = []
  include Aws::Structure
end