Class: Aws::Appflow::Types::RedshiftConnectorProfileProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appflow/types.rb

Overview

The connector-specific profile properties when using Amazon Redshift.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_nameString

A name for the associated Amazon S3 bucket.

Returns:

  • (String)


3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-appflow/types.rb', line 3763

class RedshiftConnectorProfileProperties < Struct.new(
  :database_url,
  :bucket_name,
  :bucket_prefix,
  :role_arn,
  :data_api_role_arn,
  :is_redshift_serverless,
  :cluster_identifier,
  :workgroup_name,
  :database_name)
  SENSITIVE = []
  include Aws::Structure
end

#bucket_prefixString

The object key for the destination bucket in which Amazon AppFlow places the files.

Returns:

  • (String)


3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-appflow/types.rb', line 3763

class RedshiftConnectorProfileProperties < Struct.new(
  :database_url,
  :bucket_name,
  :bucket_prefix,
  :role_arn,
  :data_api_role_arn,
  :is_redshift_serverless,
  :cluster_identifier,
  :workgroup_name,
  :database_name)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_identifierString

The unique ID that's assigned to an Amazon Redshift cluster.

Returns:

  • (String)


3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-appflow/types.rb', line 3763

class RedshiftConnectorProfileProperties < Struct.new(
  :database_url,
  :bucket_name,
  :bucket_prefix,
  :role_arn,
  :data_api_role_arn,
  :is_redshift_serverless,
  :cluster_identifier,
  :workgroup_name,
  :database_name)
  SENSITIVE = []
  include Aws::Structure
end

#data_api_role_arnString

The Amazon Resource Name (ARN) of an IAM role that permits Amazon AppFlow to access your Amazon Redshift database through the Data API. For more information, and for the polices that you attach to this role, see Allow Amazon AppFlow to access Amazon Redshift databases with the Data API.

Returns:

  • (String)


3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-appflow/types.rb', line 3763

class RedshiftConnectorProfileProperties < Struct.new(
  :database_url,
  :bucket_name,
  :bucket_prefix,
  :role_arn,
  :data_api_role_arn,
  :is_redshift_serverless,
  :cluster_identifier,
  :workgroup_name,
  :database_name)
  SENSITIVE = []
  include Aws::Structure
end

#database_nameString

The name of an Amazon Redshift database.

Returns:

  • (String)


3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-appflow/types.rb', line 3763

class RedshiftConnectorProfileProperties < Struct.new(
  :database_url,
  :bucket_name,
  :bucket_prefix,
  :role_arn,
  :data_api_role_arn,
  :is_redshift_serverless,
  :cluster_identifier,
  :workgroup_name,
  :database_name)
  SENSITIVE = []
  include Aws::Structure
end

#database_urlString

The JDBC URL of the Amazon Redshift cluster.

Returns:

  • (String)


3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-appflow/types.rb', line 3763

class RedshiftConnectorProfileProperties < Struct.new(
  :database_url,
  :bucket_name,
  :bucket_prefix,
  :role_arn,
  :data_api_role_arn,
  :is_redshift_serverless,
  :cluster_identifier,
  :workgroup_name,
  :database_name)
  SENSITIVE = []
  include Aws::Structure
end

#is_redshift_serverlessBoolean

Indicates whether the connector profile defines a connection to an Amazon Redshift Serverless data warehouse.

Returns:

  • (Boolean)


3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-appflow/types.rb', line 3763

class RedshiftConnectorProfileProperties < Struct.new(
  :database_url,
  :bucket_name,
  :bucket_prefix,
  :role_arn,
  :data_api_role_arn,
  :is_redshift_serverless,
  :cluster_identifier,
  :workgroup_name,
  :database_name)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of IAM role that grants Amazon Redshift read-only access to Amazon S3. For more information, and for the polices that you attach to this role, see Allow Amazon Redshift to access your Amazon AppFlow data in Amazon S3.

Returns:

  • (String)


3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-appflow/types.rb', line 3763

class RedshiftConnectorProfileProperties < Struct.new(
  :database_url,
  :bucket_name,
  :bucket_prefix,
  :role_arn,
  :data_api_role_arn,
  :is_redshift_serverless,
  :cluster_identifier,
  :workgroup_name,
  :database_name)
  SENSITIVE = []
  include Aws::Structure
end

#workgroup_nameString

The name of an Amazon Redshift workgroup.

Returns:

  • (String)


3763
3764
3765
3766
3767
3768
3769
3770
3771
3772
3773
3774
3775
# File 'lib/aws-sdk-appflow/types.rb', line 3763

class RedshiftConnectorProfileProperties < Struct.new(
  :database_url,
  :bucket_name,
  :bucket_prefix,
  :role_arn,
  :data_api_role_arn,
  :is_redshift_serverless,
  :cluster_identifier,
  :workgroup_name,
  :database_name)
  SENSITIVE = []
  include Aws::Structure
end