Class: Aws::Appflow::Types::SAPODataConnectorProfileProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appflow/types.rb

Overview

The connector-specific profile properties required when using SAPOData.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_host_url ⇒ String

The location of the SAPOData resource.

Returns:

  • (String)


4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
# File 'lib/aws-sdk-appflow/types.rb', line 4200

class SAPODataConnectorProfileProperties < Struct.new(
  :application_host_url,
  :application_service_path,
  :port_number,
  :client_number,
  :logon_language,
  :private_link_service_name,
  :o_auth_properties,
  :disable_sso)
  SENSITIVE = []
  include Aws::Structure
end

#application_service_path ⇒ String

The application path to catalog service.

Returns:

  • (String)


4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
# File 'lib/aws-sdk-appflow/types.rb', line 4200

class SAPODataConnectorProfileProperties < Struct.new(
  :application_host_url,
  :application_service_path,
  :port_number,
  :client_number,
  :logon_language,
  :private_link_service_name,
  :o_auth_properties,
  :disable_sso)
  SENSITIVE = []
  include Aws::Structure
end

#client_number ⇒ String

The client number for the client creating the connection.

Returns:

  • (String)


4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
# File 'lib/aws-sdk-appflow/types.rb', line 4200

class SAPODataConnectorProfileProperties < Struct.new(
  :application_host_url,
  :application_service_path,
  :port_number,
  :client_number,
  :logon_language,
  :private_link_service_name,
  :o_auth_properties,
  :disable_sso)
  SENSITIVE = []
  include Aws::Structure
end

#disable_sso ⇒ Boolean

If you set this parameter to true, Amazon AppFlow bypasses the single sign-on (SSO) settings in your SAP account when it accesses your SAP OData instance.

Whether you need this option depends on the types of credentials that you applied to your SAP OData connection profile. If your profile uses basic authentication credentials, SAP SSO can prevent Amazon AppFlow from connecting to your account with your username and password. In this case, bypassing SSO makes it possible for Amazon AppFlow to connect successfully. However, if your profile uses OAuth credentials, this parameter has no affect.

Returns:

  • (Boolean)


4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
# File 'lib/aws-sdk-appflow/types.rb', line 4200

class SAPODataConnectorProfileProperties < Struct.new(
  :application_host_url,
  :application_service_path,
  :port_number,
  :client_number,
  :logon_language,
  :private_link_service_name,
  :o_auth_properties,
  :disable_sso)
  SENSITIVE = []
  include Aws::Structure
end

#logon_language ⇒ String

The logon language of SAPOData instance.

Returns:

  • (String)


4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
# File 'lib/aws-sdk-appflow/types.rb', line 4200

class SAPODataConnectorProfileProperties < Struct.new(
  :application_host_url,
  :application_service_path,
  :port_number,
  :client_number,
  :logon_language,
  :private_link_service_name,
  :o_auth_properties,
  :disable_sso)
  SENSITIVE = []
  include Aws::Structure
end

#o_auth_properties ⇒ Types::OAuthProperties

The SAPOData OAuth properties required for OAuth type authentication.



4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
# File 'lib/aws-sdk-appflow/types.rb', line 4200

class SAPODataConnectorProfileProperties < Struct.new(
  :application_host_url,
  :application_service_path,
  :port_number,
  :client_number,
  :logon_language,
  :private_link_service_name,
  :o_auth_properties,
  :disable_sso)
  SENSITIVE = []
  include Aws::Structure
end

#port_number ⇒ Integer

The port number of the SAPOData instance.

Returns:

  • (Integer)


4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
# File 'lib/aws-sdk-appflow/types.rb', line 4200

class SAPODataConnectorProfileProperties < Struct.new(
  :application_host_url,
  :application_service_path,
  :port_number,
  :client_number,
  :logon_language,
  :private_link_service_name,
  :o_auth_properties,
  :disable_sso)
  SENSITIVE = []
  include Aws::Structure
end

The SAPOData Private Link service name to be used for private data transfers.

Returns:

  • (String)


4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
# File 'lib/aws-sdk-appflow/types.rb', line 4200

class SAPODataConnectorProfileProperties < Struct.new(
  :application_host_url,
  :application_service_path,
  :port_number,
  :client_number,
  :logon_language,
  :private_link_service_name,
  :o_auth_properties,
  :disable_sso)
  SENSITIVE = []
  include Aws::Structure
end