Class: Aws::Appflow::Types::SalesforceConnectorProfileProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appflow/types.rb

Overview

The connector-specific profile properties required when using Salesforce.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_urlString

The location of the Salesforce resource.

Returns:

  • (String)


4456
4457
4458
4459
4460
4461
4462
# File 'lib/aws-sdk-appflow/types.rb', line 4456

class SalesforceConnectorProfileProperties < Struct.new(
  :instance_url,
  :is_sandbox_environment,
  :use_private_link_for_metadata_and_authorization)
  SENSITIVE = []
  include Aws::Structure
end

#is_sandbox_environmentBoolean

Indicates whether the connector profile applies to a sandbox or production environment.

Returns:

  • (Boolean)


4456
4457
4458
4459
4460
4461
4462
# File 'lib/aws-sdk-appflow/types.rb', line 4456

class SalesforceConnectorProfileProperties < Struct.new(
  :instance_url,
  :is_sandbox_environment,
  :use_private_link_for_metadata_and_authorization)
  SENSITIVE = []
  include Aws::Structure
end

If the connection mode for the connector profile is private, this parameter sets whether Amazon AppFlow uses the private network to send metadata and authorization calls to Salesforce. Amazon AppFlow sends private calls through Amazon Web Services PrivateLink. These calls travel through Amazon Web Services infrastructure without being exposed to the public internet.

Set either of the following values:

true

: Amazon AppFlow sends all calls to Salesforce over the private network.

These private calls are:

* Calls to get metadata about your Salesforce records. This
metadata describes your Salesforce objects and their fields.

* Calls to get or refresh access tokens that allow Amazon AppFlow
to access your Salesforce records.

* Calls to transfer your Salesforce records as part of a flow run.

false

: The default value. Amazon AppFlow sends some calls to Salesforce privately and other calls over the public internet.

The public calls are:

* Calls to get metadata about your Salesforce records.

* Calls to get or refresh access tokens.

The private calls are:

* Calls to transfer your Salesforce records as part of a flow run.

^

Returns:

  • (Boolean)


4456
4457
4458
4459
4460
4461
4462
# File 'lib/aws-sdk-appflow/types.rb', line 4456

class SalesforceConnectorProfileProperties < Struct.new(
  :instance_url,
  :is_sandbox_environment,
  :use_private_link_for_metadata_and_authorization)
  SENSITIVE = []
  include Aws::Structure
end