Class: Aws::Appflow::Types::SnowflakeConnectorProfileCredentials

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-appflow/types.rb

Overview

The connector-specific profile credentials required when using Snowflake.

Constant Summary collapse

SENSITIVE =
[:password, :private_key]

Instance Attribute Summary collapse

Instance Attribute Details

#passwordString

The password that corresponds to the user name.

Returns:

  • (String)


4957
4958
4959
4960
4961
4962
4963
# File 'lib/aws-sdk-appflow/types.rb', line 4957

class SnowflakeConnectorProfileCredentials < Struct.new(
  :username,
  :password,
  :private_key)
  SENSITIVE = [:password, :private_key]
  include Aws::Structure
end

#private_keyString

The RSA private key used for key pair authentication with Snowflake. Provide this instead of a password when your Snowflake account uses key pair authentication.

Returns:

  • (String)


4957
4958
4959
4960
4961
4962
4963
# File 'lib/aws-sdk-appflow/types.rb', line 4957

class SnowflakeConnectorProfileCredentials < Struct.new(
  :username,
  :password,
  :private_key)
  SENSITIVE = [:password, :private_key]
  include Aws::Structure
end

#usernameString

The name of the user.

Returns:

  • (String)


4957
4958
4959
4960
4961
4962
4963
# File 'lib/aws-sdk-appflow/types.rb', line 4957

class SnowflakeConnectorProfileCredentials < Struct.new(
  :username,
  :password,
  :private_key)
  SENSITIVE = [:password, :private_key]
  include Aws::Structure
end