Class: Aws::Appflow::Types::SourceConnectorProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::Appflow::Types::SourceConnectorProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appflow/types.rb
Overview
Specifies the information that is required to query a particular connector.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amplitude ⇒ Types::AmplitudeSourceProperties
Specifies the information that is required for querying Amplitude.
-
#custom_connector ⇒ Types::CustomConnectorSourceProperties
The properties that are applied when the custom connector is being used as a source.
-
#datadog ⇒ Types::DatadogSourceProperties
Specifies the information that is required for querying Datadog.
-
#dynatrace ⇒ Types::DynatraceSourceProperties
Specifies the information that is required for querying Dynatrace.
-
#google_analytics ⇒ Types::GoogleAnalyticsSourceProperties
Specifies the information that is required for querying Google Analytics.
-
#infor_nexus ⇒ Types::InforNexusSourceProperties
Specifies the information that is required for querying Infor Nexus.
-
#marketo ⇒ Types::MarketoSourceProperties
Specifies the information that is required for querying Marketo.
-
#pardot ⇒ Types::PardotSourceProperties
Specifies the information that is required for querying Salesforce Pardot.
-
#s3 ⇒ Types::S3SourceProperties
Specifies the information that is required for querying Amazon S3.
-
#salesforce ⇒ Types::SalesforceSourceProperties
Specifies the information that is required for querying Salesforce.
-
#sapo_data ⇒ Types::SAPODataSourceProperties
The properties that are applied when using SAPOData as a flow source.
-
#service_now ⇒ Types::ServiceNowSourceProperties
Specifies the information that is required for querying ServiceNow.
-
#singular ⇒ Types::SingularSourceProperties
Specifies the information that is required for querying Singular.
-
#slack ⇒ Types::SlackSourceProperties
Specifies the information that is required for querying Slack.
-
#trendmicro ⇒ Types::TrendmicroSourceProperties
Specifies the information that is required for querying Trend Micro.
-
#veeva ⇒ Types::VeevaSourceProperties
Specifies the information that is required for querying Veeva.
-
#zendesk ⇒ Types::ZendeskSourceProperties
Specifies the information that is required for querying Zendesk.
Instance Attribute Details
#amplitude ⇒ Types::AmplitudeSourceProperties
Specifies the information that is required for querying Amplitude.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#custom_connector ⇒ Types::CustomConnectorSourceProperties
The properties that are applied when the custom connector is being used as a source.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#datadog ⇒ Types::DatadogSourceProperties
Specifies the information that is required for querying Datadog.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#dynatrace ⇒ Types::DynatraceSourceProperties
Specifies the information that is required for querying Dynatrace.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#google_analytics ⇒ Types::GoogleAnalyticsSourceProperties
Specifies the information that is required for querying Google Analytics.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#infor_nexus ⇒ Types::InforNexusSourceProperties
Specifies the information that is required for querying Infor Nexus.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#marketo ⇒ Types::MarketoSourceProperties
Specifies the information that is required for querying Marketo.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#pardot ⇒ Types::PardotSourceProperties
Specifies the information that is required for querying Salesforce Pardot.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#s3 ⇒ Types::S3SourceProperties
Specifies the information that is required for querying Amazon S3.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#salesforce ⇒ Types::SalesforceSourceProperties
Specifies the information that is required for querying Salesforce.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#sapo_data ⇒ Types::SAPODataSourceProperties
The properties that are applied when using SAPOData as a flow source.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#service_now ⇒ Types::ServiceNowSourceProperties
Specifies the information that is required for querying ServiceNow.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#singular ⇒ Types::SingularSourceProperties
Specifies the information that is required for querying Singular.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#slack ⇒ Types::SlackSourceProperties
Specifies the information that is required for querying Slack.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#trendmicro ⇒ Types::TrendmicroSourceProperties
Specifies the information that is required for querying Trend Micro.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#veeva ⇒ Types::VeevaSourceProperties
Specifies the information that is required for querying Veeva.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |
#zendesk ⇒ Types::ZendeskSourceProperties
Specifies the information that is required for querying Zendesk.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 |
# File 'lib/aws-sdk-appflow/types.rb', line 5144 class SourceConnectorProperties < Struct.new( :amplitude, :datadog, :dynatrace, :google_analytics, :infor_nexus, :marketo, :s3, :salesforce, :service_now, :singular, :slack, :trendmicro, :veeva, :zendesk, :sapo_data, :custom_connector, :pardot) SENSITIVE = [] include Aws::Structure end |