Class: Aws::Appflow::Types::ConnectorOAuthRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Appflow::Types::ConnectorOAuthRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appflow/types.rb
Overview
Used by select connectors for which the OAuth workflow is supported, such as Salesforce, Google Analytics, Marketo, Zendesk, and Slack.
Constant Summary collapse
- SENSITIVE =
[:code_verifier]
Instance Attribute Summary collapse
-
#auth_code ⇒ String
The code provided by the connector when it has been authenticated via the connected app.
-
#code_verifier ⇒ String
The code verifier used in the PKCE (Proof Key for Code Exchange) OAuth flow.
-
#redirect_uri ⇒ String
The URL to which the authentication server redirects the browser after authorization has been granted.
Instance Attribute Details
#auth_code ⇒ String
The code provided by the connector when it has been authenticated via the connected app.
767 768 769 770 771 772 773 |
# File 'lib/aws-sdk-appflow/types.rb', line 767 class ConnectorOAuthRequest < Struct.new( :auth_code, :redirect_uri, :code_verifier) SENSITIVE = [:code_verifier] include Aws::Structure end |
#code_verifier ⇒ String
The code verifier used in the PKCE (Proof Key for Code Exchange) OAuth flow.
767 768 769 770 771 772 773 |
# File 'lib/aws-sdk-appflow/types.rb', line 767 class ConnectorOAuthRequest < Struct.new( :auth_code, :redirect_uri, :code_verifier) SENSITIVE = [:code_verifier] include Aws::Structure end |
#redirect_uri ⇒ String
The URL to which the authentication server redirects the browser after authorization has been granted.
767 768 769 770 771 772 773 |
# File 'lib/aws-sdk-appflow/types.rb', line 767 class ConnectorOAuthRequest < Struct.new( :auth_code, :redirect_uri, :code_verifier) SENSITIVE = [:code_verifier] include Aws::Structure end |