Class: Aws::Appflow::Types::ConnectorProfile
- Inherits:
-
Struct
- Object
- Struct
- Aws::Appflow::Types::ConnectorProfile
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appflow/types.rb
Overview
Describes an instance of a connector. This includes the provided name, credentials ARN, connection-mode, and so on. To keep the API intuitive and extensible, the fields that are common to all types of connector profiles are explicitly specified at the top level. The rest of the connector-specific properties are available via the ‘connectorProfileProperties` field.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_mode ⇒ String
Indicates the connection mode and if it is public or private.
-
#connector_label ⇒ String
The label for the connector profile being created.
-
#connector_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the connector profile.
-
#connector_profile_name ⇒ String
The name of the connector profile.
-
#connector_profile_properties ⇒ Types::ConnectorProfileProperties
The connector-specific properties of the profile configuration.
-
#connector_type ⇒ String
The type of connector, such as Salesforce, Amplitude, and so on.
-
#created_at ⇒ Time
Specifies when the connector profile was created.
-
#credentials_arn ⇒ String
The Amazon Resource Name (ARN) of the connector profile credentials.
-
#last_updated_at ⇒ Time
Specifies when the connector profile was last updated.
-
#private_connection_provisioning_state ⇒ Types::PrivateConnectionProvisioningState
Specifies the private connection provisioning state.
Instance Attribute Details
#connection_mode ⇒ String
Indicates the connection mode and if it is public or private.
924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-appflow/types.rb', line 924 class ConnectorProfile < Struct.new( :connector_profile_arn, :connector_profile_name, :connector_type, :connector_label, :connection_mode, :credentials_arn, :connector_profile_properties, :created_at, :last_updated_at, :private_connection_provisioning_state) SENSITIVE = [] include Aws::Structure end |
#connector_label ⇒ String
The label for the connector profile being created.
924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-appflow/types.rb', line 924 class ConnectorProfile < Struct.new( :connector_profile_arn, :connector_profile_name, :connector_type, :connector_label, :connection_mode, :credentials_arn, :connector_profile_properties, :created_at, :last_updated_at, :private_connection_provisioning_state) SENSITIVE = [] include Aws::Structure end |
#connector_profile_arn ⇒ String
The Amazon Resource Name (ARN) of the connector profile.
924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-appflow/types.rb', line 924 class ConnectorProfile < Struct.new( :connector_profile_arn, :connector_profile_name, :connector_type, :connector_label, :connection_mode, :credentials_arn, :connector_profile_properties, :created_at, :last_updated_at, :private_connection_provisioning_state) SENSITIVE = [] include Aws::Structure end |
#connector_profile_name ⇒ String
The name of the connector profile. The name is unique for each ‘ConnectorProfile` in the Amazon Web Services account.
924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-appflow/types.rb', line 924 class ConnectorProfile < Struct.new( :connector_profile_arn, :connector_profile_name, :connector_type, :connector_label, :connection_mode, :credentials_arn, :connector_profile_properties, :created_at, :last_updated_at, :private_connection_provisioning_state) SENSITIVE = [] include Aws::Structure end |
#connector_profile_properties ⇒ Types::ConnectorProfileProperties
The connector-specific properties of the profile configuration.
924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-appflow/types.rb', line 924 class ConnectorProfile < Struct.new( :connector_profile_arn, :connector_profile_name, :connector_type, :connector_label, :connection_mode, :credentials_arn, :connector_profile_properties, :created_at, :last_updated_at, :private_connection_provisioning_state) SENSITIVE = [] include Aws::Structure end |
#connector_type ⇒ String
The type of connector, such as Salesforce, Amplitude, and so on.
924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-appflow/types.rb', line 924 class ConnectorProfile < Struct.new( :connector_profile_arn, :connector_profile_name, :connector_type, :connector_label, :connection_mode, :credentials_arn, :connector_profile_properties, :created_at, :last_updated_at, :private_connection_provisioning_state) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
Specifies when the connector profile was created.
924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-appflow/types.rb', line 924 class ConnectorProfile < Struct.new( :connector_profile_arn, :connector_profile_name, :connector_type, :connector_label, :connection_mode, :credentials_arn, :connector_profile_properties, :created_at, :last_updated_at, :private_connection_provisioning_state) SENSITIVE = [] include Aws::Structure end |
#credentials_arn ⇒ String
The Amazon Resource Name (ARN) of the connector profile credentials.
924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-appflow/types.rb', line 924 class ConnectorProfile < Struct.new( :connector_profile_arn, :connector_profile_name, :connector_type, :connector_label, :connection_mode, :credentials_arn, :connector_profile_properties, :created_at, :last_updated_at, :private_connection_provisioning_state) SENSITIVE = [] include Aws::Structure end |
#last_updated_at ⇒ Time
Specifies when the connector profile was last updated.
924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-appflow/types.rb', line 924 class ConnectorProfile < Struct.new( :connector_profile_arn, :connector_profile_name, :connector_type, :connector_label, :connection_mode, :credentials_arn, :connector_profile_properties, :created_at, :last_updated_at, :private_connection_provisioning_state) SENSITIVE = [] include Aws::Structure end |
#private_connection_provisioning_state ⇒ Types::PrivateConnectionProvisioningState
Specifies the private connection provisioning state.
924 925 926 927 928 929 930 931 932 933 934 935 936 937 |
# File 'lib/aws-sdk-appflow/types.rb', line 924 class ConnectorProfile < Struct.new( :connector_profile_arn, :connector_profile_name, :connector_type, :connector_label, :connection_mode, :credentials_arn, :connector_profile_properties, :created_at, :last_updated_at, :private_connection_provisioning_state) SENSITIVE = [] include Aws::Structure end |