Class: Aws::Appflow::Types::CustomerProfilesDestinationProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::Appflow::Types::CustomerProfilesDestinationProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appflow/types.rb
Overview
The properties that are applied when Connect Customer Customer Profiles is used as a destination.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_name ⇒ String
The unique name of the Connect Customer Customer Profiles domain.
-
#object_type_name ⇒ String
The object specified in the Connect Customer Customer Profiles flow destination.
Instance Attribute Details
#domain_name ⇒ String
The unique name of the Connect Customer Customer Profiles domain.
1612 1613 1614 1615 1616 1617 |
# File 'lib/aws-sdk-appflow/types.rb', line 1612 class CustomerProfilesDestinationProperties < Struct.new( :domain_name, :object_type_name) SENSITIVE = [] include Aws::Structure end |
#object_type_name ⇒ String
The object specified in the Connect Customer Customer Profiles flow destination.
1612 1613 1614 1615 1616 1617 |
# File 'lib/aws-sdk-appflow/types.rb', line 1612 class CustomerProfilesDestinationProperties < Struct.new( :domain_name, :object_type_name) SENSITIVE = [] include Aws::Structure end |