Class: Aws::Appflow::Types::DescribeConnectorProfilesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Appflow::Types::DescribeConnectorProfilesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-appflow/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_label ⇒ String
The name of the connector.
-
#connector_profile_names ⇒ Array<String>
The name of the connector profile.
-
#connector_type ⇒ String
The type of connector, such as Salesforce, Amplitude, and so on.
-
#max_results ⇒ Integer
Specifies the maximum number of items that should be returned in the result set.
-
#next_token ⇒ String
The pagination token for the next page of data.
Instance Attribute Details
#connector_label ⇒ String
The name of the connector. The name is unique for each
ConnectorRegistration in your Amazon Web Services account. Only
needed if calling for CUSTOMCONNECTOR connector type/.
1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-appflow/types.rb', line 1836 class DescribeConnectorProfilesRequest < Struct.new( :connector_profile_names, :connector_type, :connector_label, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#connector_profile_names ⇒ Array<String>
The name of the connector profile. The name is unique for each
ConnectorProfile in the Amazon Web Services account.
1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-appflow/types.rb', line 1836 class DescribeConnectorProfilesRequest < Struct.new( :connector_profile_names, :connector_type, :connector_label, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#connector_type ⇒ String
The type of connector, such as Salesforce, Amplitude, and so on.
1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-appflow/types.rb', line 1836 class DescribeConnectorProfilesRequest < Struct.new( :connector_profile_names, :connector_type, :connector_label, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Specifies the maximum number of items that should be returned in the
result set. The default for maxResults is 20 (for all paginated
API operations).
1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-appflow/types.rb', line 1836 class DescribeConnectorProfilesRequest < Struct.new( :connector_profile_names, :connector_type, :connector_label, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token for the next page of data.
1836 1837 1838 1839 1840 1841 1842 1843 1844 |
# File 'lib/aws-sdk-appflow/types.rb', line 1836 class DescribeConnectorProfilesRequest < Struct.new( :connector_profile_names, :connector_type, :connector_label, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |