Method: Aws::Appflow::Types::RegisterConnectorRequest#client_token
- Defined in:
- lib/aws-sdk-appflow/types.rb
#client_token ⇒ String
The clientToken parameter is an idempotency token. It ensures that your RegisterConnector request completes only once. You choose the value to pass. For example, if you don’t receive a response from your request, you can safely retry the request with the same clientToken parameter value.
If you omit a clientToken value, the Amazon Web Services SDK that you are using inserts a value for you. This way, the SDK can safely retry requests multiple times after a network error. You must provide your own value for other use cases.
If you specify input parameters that differ from your first request, an error occurs. If you use a different value for clientToken, Amazon AppFlow considers it a new call to RegisterConnector. The token is active for 8 hours.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3855 3856 3857 3858 3859 3860 3861 3862 3863 |
# File 'lib/aws-sdk-appflow/types.rb', line 3855 class RegisterConnectorRequest < Struct.new( :connector_label, :description, :connector_provisioning_type, :connector_provisioning_config, :client_token) SENSITIVE = [] include Aws::Structure end |